# 1 skyctl安装

### 1.1 skyctl的安装方式

1.配置python环境变量

2.使用 pip install skyctl 安装skyctl 工具



### 1.2 skyctl的更新方式

使用指令：pip install --upgrade skyctl 

# 2 skyctl使用

### 2.1 用户登录

skyctl login 进行身份校验

### 2.3 命令行操作

#### 2.3.1 skyctl upload

上传skypilot配置文件，所需参数：

（1）直接回车，将文件上传到default namespace

（2）输入namespace，将文件上传到指定的namespace

#### 2.3.2 skyctl check

检查用户授权文件

#### 2.3.3 skyctl namespace

用户namespace操作
